==> cego-2.6.18.tar.gz: cego-2.6.18/src/CegoProcFetch.h <==
#ifndef _CEGOPROCFETCH_H_INCLUDED_
#define _CEGOPROCFETCH_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoProcFetch.h
// ----------------
// Cego procedure fetch structure class definition
//                                                         
// Design and Implementation by Bjoern Lemke               
//                                                         
// (C)opyright 2000-2010 Bjoern Lemke                        
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: CegoProcFetch
// 
// Description: 
//
// Status: QG-2.6
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include <lfc/Chain.h>

// cego includes
#include "CegoProcVar.h"
#include "CegoFieldValue.h"
#include "CegoProcStmt.h"

class CegoProcFetch {
    
 public:
    
    CegoProcFetch();
    CegoProcFetch(CegoProcCursor *pCur, const ListT<CegoProcVar*>& varList);
    ~CegoProcFetch();

    bool fetch();

    CegoProcFetch& operator = ( const CegoProcFetch& pf);

    Chain toChain() const;

    friend ostream& operator << (ostream& s, const CegoProcFetch& pf);
      
 private:
    
    CegoProcCursor* _pCur;
    ListT<CegoProcVar*> _varList;

};

#endif

==> cego-2.8.5.tar.gz: cego-2.8.5/src/CegoProcFetch.h <==
#ifndef _CEGOPROCFETCH_H_INCLUDED_
#define _CEGOPROCFETCH_H_INCLUDED_
///////////////////////////////////////////////////////////////////////////////
//                                                         
// CegoProcFetch.h
// ----------------
// Cego procedure fetch structure class definition
//                                                         
// Design and Implementation by Bjoern Lemke               
//                                                         
// (C)opyright 2000-2010 Bjoern Lemke                        
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2, or (at your option)
// any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; see the file COPYING.  If not, write to
// the Free Software Foundation, 59 Temple Place - Suite 330,
// Boston, MA 02111-1307, USA.
//
// INTERFACE MODULE
//
// Class: CegoProcFetch
// 
// Description: 
//
// Status: QG-2.6
//
///////////////////////////////////////////////////////////////////////////////

// base includes
#include <lfc/Chain.h>

// cego includes
#include "CegoProcVar.h"
#include "CegoFieldValue.h"
#include "CegoProcStmt.h"

class CegoProcFetch {
    
 public:
    
    CegoProcFetch();
    // CegoProcFetch(CegoProcCursor *pCur, const ListT<CegoProcVar*>& varList);
    CegoProcFetch(CegoProcCursor *pCur, const ListT<Chain>& varList);
    ~CegoProcFetch();

    void setBlock(CegoProcBlock *pBlock);

    bool fetch();

    CegoProcFetch& operator = ( const CegoProcFetch& pf);

    Chain toChain() const;

    friend ostream& operator << (ostream& s, const CegoProcFetch& pf);
      
 private:
    
    CegoProcCursor* _pCur;
    // ListT<CegoProcVar*> _varList;
    ListT<Chain> _varList;

    CegoProcBlock* _pBlock;
};

#endif
